########
defaults
########

This file simply defines a bunch of default and allowed values for ROMSearch. As such, it's a bit of a mess and
does not have any rigorously defined syntax

Defaults
========

.. literalinclude:: ../../romsearch/configs/defaults.yml